==> humhub-1.17.5.zip: humhub-1.17.5/protected/humhub/modules/admin/messages/sr/modules.php <==
<?php

return [
    '%moduleName% - Set as default module' => '%moduleName% - Postavi kao podraumevani modul',
    'Always activated' => 'Uvek aktivirano',
    'Are you sure? *ALL* module data will be lost!' => 'Jeste li sigurni? * SVI * podaci modula će biti izgubljeni!',
    'Are you sure? *ALL* module related data and files will be lost!' => 'Jeste li sigurni? * SVI * modul povezani podaci i datoteke bit će izgubljeni!',
    'Close' => 'Zatvori',
    'Could not find requested module!' => 'Traženi modul nije pronađen.',
    'Deactivated' => 'Deaktivirano',
    'Deactivation of this module has not been completed yet. Please retry in a few minutes.' => 'Deaktivacija ovog modula nije završena. Probajte opet za nekolio minuta.',
    'Enable module...' => 'Omogući modul...',
    'Enabled' => 'Omogućeno',
    'Here you can choose whether or not a module should be automatically activated on a space or user profile. If the module should be activated, choose "always activated".' => 'Ovdje možete odabrati hoće li modul biti automatski aktiviran na prostoru ili korisničkom profilu. Ako bi modul trebao da bude aktiviran, odaberite "uviek aktiviran".',
    'Module deactivation in progress. This process may take a moment.' => 'Deaktivacija modula je u progresu. Ovaj proces može da potraje malo',
    'Module path %path% is not writeable!' => 'Put modula %path% nije upisiv!',
    'Save' => 'Sacuvaj',
    'Space default state' => 'Podrazumevano stanje prostora',
    'Spaces' => 'Prostori',
    'User default state' => 'Podrazumevano stanje korisnika',
    'Users' => 'Korisnici',
    'Module uninstall in progress. This process may take a moment.' => '',
    'Not available' => '',
    'The module is currently being used by {nbContainers} users or spaces. If you change its availability, all content created with the module will be lost. Proceed?' => '',
    'Uninstallation of this module has not been completed yet. It will be removed in a few minutes.' => '',
];

==> humhub-1.18.0.zip: humhub-1.18.0/protected/humhub/modules/admin/messages/sr/modules.php <==
<?php

return [
    '%moduleName% - Set as default module' => '%moduleName% - Postavi kao podraumevani modul',
    'Always activated' => 'Uvek aktivirano',
    'Could not find requested module!' => 'Traženi modul nije pronađen.',
    'Deactivated' => 'Deaktivirano',
    'Deactivation of this module has not been completed yet. Please retry in a few minutes.' => 'Deaktivacija ovog modula nije završena. Probajte opet za nekolio minuta.',
    'Enable module...' => 'Omogući modul...',
    'Enabled' => 'Omogućeno',
    'Here you can choose whether or not a module should be automatically activated on a space or user profile. If the module should be activated, choose "always activated".' => 'Ovdje možete odabrati hoće li modul biti automatski aktiviran na prostoru ili korisničkom profilu. Ako bi modul trebao da bude aktiviran, odaberite "uviek aktiviran".',
    'Module deactivation in progress. This process may take a moment.' => 'Deaktivacija modula je u progresu. Ovaj proces može da potraje malo',
    'Module path %path% is not writeable!' => 'Put modula %path% nije upisiv!',
    'Save' => 'Sacuvaj',
    'Space default state' => 'Podrazumevano stanje prostora',
    'Spaces' => 'Prostori',
    'User default state' => 'Podrazumevano stanje korisnika',
    'Users' => 'Korisnici',
    'Disable Module' => '',
    'Disabling the <strong>{moduleName}</strong> module will permanently delete <strong>all</strong> module-related content.' => '',
    'Module uninstall in progress. This process may take a moment.' => '',
    'Not available' => '',
    'The module is currently being used by {nbContainers} users or spaces. If you change its availability, all content created with the module will be lost. Proceed?' => '',
    'Uninstall Module' => '',
    'Uninstallation of this module has not been completed yet. It will be removed in a few minutes.' => '',
    'Uninstalling the <strong>{moduleName}</strong> module will permanently delete <strong>all</strong> module-related content.' => '',
];
